from typing import List
from git import Repo, Commit

# Получение списка всех доступных коммитов
def get_all_commits() -> List[Commit]:
    repo = Repo('.')
    commits = list(repo.iter_commits('--all'))

    items = [ commit for commit in commits if (commit.message.lower().count("merge branch") <= 0) ][::-1]
    
    print("Commits count: {0}".format(len(items)))

    return items

# Получение новых коммитов
#  Точкой отчета новых считается последний комит,
#  на момент получения прошлой версии (используется хэш коммита)
def get_new_commits(sentry_repository_path, project_name, last_hexsha):
    commits = list()

    repository = "{}/{}".format(sentry_repository_path, project_name)
    repository = repository.replace(" ", "")
    repository = repository.replace("/", " / ")

    for commit in get_all_commits():
        name = commit.message.replace("\n", "")
        hexsha = commit.hexsha
        email = commit.author.email
        committed_datetime = commit.committed_datetime

        if (hexsha == last_hexsha):
            commits.clear()

        commits.append({
            "repository": repository,
            "id": hexsha,
            "message": name,
            "author_email": email,
            "timestamp": str(committed_datetime)
        })

    return commits

# Получения хэша последнего коммита
def get_new_hash():
    commits = list(get_all_commits())

    if len(commits) <= 0:
        return "."
    else:
        return commits[::-1][0].hexsha
